import requests
import re
import urllib.parse

import regex_patterns

# Constants for the authentication and query process
AUTH_URL = 'https://app.leak.center/uaa/oauth/token'
LEAKS_ENDPOINT = "https://app.leak.center/svc-saas/leak/search"
CLIENT_ID = 'client-api'
CLIENT_SECRET = 'comfy-litigate-embargo-forelimb'


class Auth:
    username = None
    password = None


def get_credentials():
    if Auth.username and Auth.password:
        return Auth.username, Auth.password
    with open("auth.txt", "r") as f:
        return f.read().strip().split(',')


def get_access_token(username, password):
    data = {
        'grant_type': 'password',
        'username': username,
        'password': password,
        'client_id': CLIENT_ID,
        'client_secret': CLIENT_SECRET
    }
    response = requests.post(AUTH_URL, data=data)
    response.raise_for_status()
    token = response.json()['access_token']
    print(f"Fetched token: {token[:10]}...")  # Show only the first 10 characters for security
    return token


def get_query_input():
    try:
        with open("input.txt", "r") as f:
            return f.read().strip()
    except FileNotFoundError:
        return "queryString"  # This should be replaced with actual in-memory variable if available


def get_date_range():
    try:
        with open("DateRange.txt", "r") as f:
            return f.read().strip()
    except FileNotFoundError:
        return ""  # This should be replaced with actual in-memory variable if available


def get_tags():
    with open("tags.txt", "r") as f:
        return [line.strip() for line in f]


def query_and_process_leaks(domain, token, date_range, tags):
    page = 0
    all_results = []
    with open("AccountDto.txt", "w") as outfile:
        while True:
            params = {
                "page": page,
                "size": 100,
                "sort": "createdAt,desc",
                "length": 500,
                "highlight": "true",
                "query": domain + (" AND createdAt:[" + date_range + "]" if date_range else "")
            }

            # Correctly construct the full query URL with consistent string delimiters
            query_params = '&'.join(f"{k}={urllib.parse.quote(str(v), safe='')}" for k, v in params.items())
            query_url = f"{LEAKS_ENDPOINT}?{query_params}"
            print(f"Query URL: {query_url}")  # Debugging output: Show the actual query URL

            headers = {"Authorization": f"Bearer {token}"}
            response = requests.get(LEAKS_ENDPOINT, params=params, headers=headers)
            response.raise_for_status()
            data = response.json()

            filtered_content = filter_results(data['content'], tags)
            for item in filtered_content:
                outfile.write(';'.join(f'{key}:"{value}"' for key, value in item.items()) + '\n')
            all_results.extend(filtered_content)

            print(f"Page {page} processed, total entries collected: {len(all_results)}")  # Debugging output

            if data['last']:
                break
            page += 1
    return all_results


def is_valid_server(server):
    """
    Check if the server string is a valid URL format.
    """
    valid_server_pattern = re.compile(
        r"^(https?://|http://|android://|ftp://|ttps://|ttp://|tps://|tp://|ps://|s://|p://|oid://)?([a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)+)(:[0-9]+)?(/[^\s]*)?$")
    return bool(valid_server_pattern.match(server))


def extract_info(input_string):
    for pattern in regex_patterns.patterns:
        match = re.search(pattern, input_string)
        if match:
            result = match.groupdict()
            if result.get('Server') and not is_valid_server(result['Server']):
                result['Server'] = None
            if result.get('Server'):
                result['Server'] = re.sub(r'^(ttps|ttp|tps|tp|ps|s|p|oid)://', '', result['Server'])
            if result.get('User') and 'https://' in result.get('User'):
                result['User'] = None

            extracted_info = dict()
            for key in ['Server', 'User', 'Password']:
                value = result.get(key, "")
                if value is None or value.lower() in ["none", ":", ";", ",", "null", "empty", "unknown"]:
                    extracted_info[key] = ""
                else:
                    extracted_info[key] = value
            return extracted_info

    return {'Server': "", 'User': "", 'Password': ""}


def filter_results(results, tags):
    filtered_content = []
    tag_pattern = re.compile("|".join(tags))
    for result in results:
        try:
            tag_found = tag_pattern.search(result['leakTags'])
        except Exception:
            tag_found = False
        if tag_found:
            content_lines = result['content'].split('\n')
            for line in content_lines:
                if "<kaduu:h>" in line:
                    clean_line = re.sub(r'<kaduu:h>|</kaduu:h>|\\', '', line)
                    data = {
                        "LeakContent": clean_line,
                        "createdAt": result['createdAt'],
                        # "leakSource": result['leakSource'],
                        # "leakSize": result['leakSize'],
                        # "leakPublishDate": result['leakPublishDate'],
                        # "leakTags": result['leakTags']
                    }
                    info = extract_info(clean_line)
                    for key, value in info.items():
                        if value:
                            data[key] = value
                    filtered_content.append(data)
        else:
            print(f"No matching tags found in leakTags: {result['leakTags']}")  # Debugging output for no match
    return filtered_content


def main():
    username, password = get_credentials()
    token = get_access_token(username, password)
    domain = get_query_input()
    date_range = get_date_range()
    tags = get_tags()
    final_results = query_and_process_leaks(domain, token, date_range, tags)
    print("Completed. Results saved to AccountDto.txt and stored in memory.")


if __name__ == "__main__":
    main()
