with open("input.txt", "r") as f:
    domain = f.read().strip()

patterns = [
    # user;password;https://server
    r'^(?P<User>[^;\s]+)\s*;\s*(?P<Password>[^;\s]+)\s*;\s*"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s;]+)"?$',
    rf"^(?P<User>[^;\s]+)\s*;\s*(?P<Password>[^;\s]+)\s*;\s*(?P<Server>[^\s;]+\.{domain}[^\s;]*)$",
    # user;password:https://server
    r'^(?P<User>[^;:\s]+)\s*;\s*(?P<Password>[^:\s]+)\s*:\s*"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?$',
    rf"^(?P<User>[^;:\s]+)\s*;\s*(?P<Password>[^:\s]+)\s*:\s*(?P<Server>[^\s:]+\.{domain}[^\s;]*)$",
    # user:password;https://server
    r'^(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^;\s]+)\s*;\s*"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s;]+)"?$',
    rf"^(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^;\s]+)\s*;\s*(?P<Server>[^\s;]+\.{domain}[^\s;]*)$",
    # https://server|user|password
    r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s|;]+)"?\s*\|\s*(?P<User>[^|]*)\s*\|\s*(?P<Password>[^\s]*)$',
    rf"^(?P<Server>[^\s]+\.{domain}[^\s]*)\s*\|\s*(?P<User>[^|\s]*)\s*\|\s*(?P<Password>[^\s]*)$",
    # android://server|user|password
    r'^(?P<Server>android://[^\s|;]+)\s*\|\s*(?P<User>[^|]*)\s*\|\s*(?P<Password>[^\s]*)$',
    # user:password:https://server
    r'^(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^:\s]+)\s*:\s*"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?$',
    rf"^(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^:\s]+)\s*:\s*(?P<Server>[^\s:]+\.{domain}[^\s:]*)$",
    # https://server:user:sub-user:password
    r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?\s*:\s*(?P<User>[^:]+:[^:]*)\s*:\s*(?P<Password>[^\s]*)$',
    # https://server:user:password
    r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?\s*:\s*(?P<User>[^:]*)\s*:\s*(?P<Password>[^:\s]*)$',
    # android://server:user:password
    r"^(?P<Server>android://[^\s:]+)\s*:\s*(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^\s]+)$",
    # https://server user:sub-user:password
    r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s]+)"?\s+(?P<User>[^:]+:[^:]*)\s*:\s*(?P<Password>[^\s]*)$',
    # android://server user:sub-user:password
    r"^(?P<Server>android://[^\s]+)\s+(?P<User>[^:]+:[^:]*)\s*:\s*(?P<Password>[^\s]*)$",
    # https://server user:password
    r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^"\s]+)"?\s+(?P<User>[^:]*)\s*:\s*(?P<Password>.*)$',
    # android://server user:password
    r"^(?P<Server>android://[^\s]+)\s+(?P<User>[^:]*)\s*:\s*(?P<Password>.*)$",
    # domain Url: https://server user:password
    rf'^{domain} Url: "?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^"\s]+)"?\s+(?P<User>[^:]*)\s*:\s*(?P<Password>.*)$',
    # user:password https://server
    r'^(?P<User>[^\s:]*)\s*:\s*(?P<Password>[^\s]*)\s+"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s]+)"?$',
    # https://server;user:password
    r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^"\s]+)"?\s*;\s*(?P<User>[^:]*)\s*:\s*(?P<Password>.*)$',
    # https://server:user
    r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?\s*:\s*(?P<User>[^:\s]+)$',
    # https://server
    r'^"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s:]+)"?\s*$',
    # user,password,https://server
    r'^(?P<User>[^,\s]+)\s*,\s*(?P<Password>[^,\s]+)\s*,\s*"?(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid)://[^"\s,]+)"?$',
    rf"^(?P<User>[^,\s]+)\s*,\s*(?P<Password>[^,\s]+)\s*,\s*(?P<Server>[^\s]+\.{domain}[^\s,]*)$",
    # server:user:sub-user:password
    rf'^(?P<Server>[^@\s]*{domain}[^\s]*)\s*:\s*(?P<User>[^:]+:[^:]*)\s*:\s*(?P<Password>[^:\s]*)$',
    rf"^/?(?P<Server>[^@\s]*{domain}[^\s]*)\s*\:\s*(?P<User>[^|\s]*)\s*\:\s*(?P<Password>[^\s]*)$",
    # server:user:password
    rf'^(?P<Server>[^@\s]*{domain}[^\s]*)\s*:\s*(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^:\s]+)$',
    # server user:password
    rf"^(?P<Server>[^@\s]*{domain}[^\s]*)\s+(?P<User>[^\s:]+)\s*:\s*(?P<Password>[^\s]+)$",
    # spaced-user:password:https://server
    r"^(?P<User>[^:]+)\s*:\s*(?P<Password>[^:\s]+)\s*:\s*(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^\s:]+)$",
    # https://server:user:spaced-password
    r"^(?P<Server>(https?|ttps|ttp|tps|tp|ps|s|p|oid):\/\/[^\s:]+)\s*:\s*(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^:]+)$",
    # javascript:;:user:password
    r"^javascript:;\s*:\s*(?P<User>[^:\s]+)\s*:\s*(?P<Password>[^\s]+)$",
    # password:user:hash
    r"(?P<Password>[^\s:]+):(?P<User>[^@|\s,]+@[^:;\s]+):(?P<Hash>[a-f0-9]{32})",
    # username:password:user
    r"^(?P<UserName>[^/.,]+):(?P<Password>[^;:\s,]+):(?P<User>[^'\"|;\s,]+@[^|;\"\s',]+)",
    # fake-server:user:password
    r"^(?P<Server>[\w\s@\=.\/&-]+)\s*:\s*(?P<User>[^:][\w@.-]+)\s*:\s*(?P<Password>[^\s]+)$",
    # user:password[without-space]
    r"^(?P<User>[^,:;|\s]+)\s*:\s*(?P<Password>[^:\s]+)$",
    # email: (user without password and server)
    r"^(?P<User>[^@|\s]+@[^:;|\s]+)\s*:\s*$",
    # useless-chars;user:password
    # r"(?<=;)(?P<User>[^;@|\s]+@[^:;|\s]+)\s*:\s*(?P<Password>[^\s]+)$",
    # :user:password
    r"^:\s*(?P<User>[^@|\s]+@[^:;|\s]+)\s*:\s*(?P<Password>[^\s]+)$",
    # date;password;user:hash
    r"^(?P<Date>[0-9-]+);(?P<Password>[^\s;]+);(?P<User>[^@|\s]+@[^:;\s]+):(?P<Hash>[a-f0-9]{32})$",
    # password,user,hash
    r"^(?P<Password>[^\s,]+),(?P<User>[^@|\s,]+@[^:;\s,]+),(?P<Hash>[a-f0-9]{32})$",
    # username,password,user
    r"^(?P<UserName>[^,]+),(?P<Password>[^;:\s,]+),(?P<User>[^'\"|;\s,]+@[^|;\"\s',]+)",
    # user password[digits]
    r"^(?P<User>[^'\"|:;\s,]+@[^|:;\"\s',]+)\s+(?P<Password>\d+)$",
    # user,password[char-digits]
    r"^(?P<User>[^'\"|:;\s,]+@[^|:;\"\s',]+),(?P<Password>[a-z0-9]+)$",
    # user;password[char-digits]
    r"^(?P<User>[^'\"|:;\s,]+@[^|:;\"\s',]+);(?P<Password>[a-z0-9]+)$",
    # user:password[with-space]
    r"^(?P<User>[^,:;|\s]+)\s*:\s*(?P<Password>[\w\s@-]+)$",
    # email in SQL
    r"(?P<User>[^'\"|:;\s,]+@[^|:;\"\s',]+)",
    # generic server name
    rf"^(?P<Server>[^@\s]+{domain}[^\s]*)$",
    # generic user name
    r"^(?P<User>[\w\s@.-]+)$",
]
